@@ -132,7 +132,10 @@ class oc_test (test.test):
 
         from pkg_resources import EntryPoint
         loader_ep = EntryPoint.parse("x="+self.test_loader)
-        loader_class = loader_ep.load(require=False)
+        loader_class = loader_ep.resolve()
+
+        import warnings
+        warnings.simplefilter("error")
 
         try:
             meta = self.distribution.metadata
@@ -397,7 +400,7 @@ def Extension(*args, **kwds):
     if '-isysroot' not in CFLAGS: # and os.path.exists('/usr/include/stdio.h'):
         # We're likely on a system with de Xcode Command Line Tools.
         # Explicitly use the most recent problems to avoid compile problems.
-        data = os.popen('xcodebuild -version -sdk macosx Path').read()
+        data = os.popen('/usr/bin/xcrun -sdk macosx --show-sdk-path').read()
         data = data.strip()
         if data:
             cflags.append('-isysroot')
